# plantpredict-python

Install **latest stable version** via: `pip install plantpredict`.
- To investigate the latest release, or previous releases:  https://github.com/plantpredict/python-sdk/releases

Install **development version** via GitHub master branch.

---

Documentation can be found at https://plantpredict-python.readthedocs.io

Email **support@plantpredict.com** to sign-up for important email updates.
